# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....appointments.resources.v_1.types.mutable_appointment import MutableAppointment
from .....coverages.resources.v_1.types.mutable_coverage import MutableCoverage
from .....patients.resources.v_1.types.patient import Patient


class PatientListItem(UniversalBaseModel):
    patient: Patient
    primary_coverage: typing.Optional[MutableCoverage] = None
    next_appointment: typing.Optional[MutableAppointment] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
