# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from ..types.encounter_external_id_uniqueness_error_type import EncounterExternalIdUniquenessErrorType


class EncounterExternalIdUniquenessError(ApiError):
    def __init__(
        self, body: EncounterExternalIdUniquenessErrorType, headers: typing.Optional[typing.Dict[str, str]] = None
    ):
        super().__init__(status_code=422, headers=headers, body=body)
