# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClaimFrequencyTypeCode(str, enum.Enum):
    ORIGINAL = "1"
    REPLACEMENT = "7"
    VOID = "8"
    _UNKNOWN = "__CLAIMFREQUENCYTYPECODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ClaimFrequencyTypeCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        original: typing.Callable[[], T_Result],
        replacement: typing.Callable[[], T_Result],
        void: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ClaimFrequencyTypeCode.ORIGINAL:
            return original()
        if self is ClaimFrequencyTypeCode.REPLACEMENT:
            return replacement()
        if self is ClaimFrequencyTypeCode.VOID:
            return void()
        return _unknown_member(self._value_)
