# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class CredentialingSpanStatus(str, enum.Enum):
    """
    Stage of a credentialing span in the credentialing workflow.
    """

    WORK_IN_PROGRESS = "work_in_progress"
    PENDING = "pending"
    EFFECTIVE = "effective"
    EXPIRED = "expired"
    _UNKNOWN = "__CREDENTIALINGSPANSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "CredentialingSpanStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        work_in_progress: typing.Callable[[], T_Result],
        pending: typing.Callable[[], T_Result],
        effective: typing.Callable[[], T_Result],
        expired: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is CredentialingSpanStatus.WORK_IN_PROGRESS:
            return work_in_progress()
        if self is CredentialingSpanStatus.PENDING:
            return pending()
        if self is CredentialingSpanStatus.EFFECTIVE:
            return effective()
        if self is CredentialingSpanStatus.EXPIRED:
            return expired()
        return _unknown_member(self._value_)
