# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .compute_all_in_network_rendering_providers_result import ComputeAllInNetworkRenderingProvidersResult
from .network_status_check_id import NetworkStatusCheckId


class ComputeAllInNetworkProvidersResponse(UniversalBaseModel):
    computed_network_status: ComputeAllInNetworkRenderingProvidersResult
    network_status_check_id: NetworkStatusCheckId = pydantic.Field()
    """
    Unique network status check ID for this request
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
