# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ExpectedNetworkStatus(str, enum.Enum):
    IN_NETWORK = "in_network"
    OUT_OF_NETWORK = "out_of_network"
    UNKNOWN = "unknown"
    _UNKNOWN = "__EXPECTEDNETWORKSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ExpectedNetworkStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        in_network: typing.Callable[[], T_Result],
        out_of_network: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ExpectedNetworkStatus.IN_NETWORK:
            return in_network()
        if self is ExpectedNetworkStatus.OUT_OF_NETWORK:
            return out_of_network()
        if self is ExpectedNetworkStatus.UNKNOWN:
            return unknown()
        return _unknown_member(self._value_)
