# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from .era_base import EraBase
from .era_id import EraId


class Era(EraBase):
    """
    Examples
    --------
    import uuid

    from candid.resources.era import Era

    Era(
        era_id=uuid.UUID(
            "4d844ef1-2253-43cd-a4f1-6db7e65cb54b",
        ),
        check_number="CHK12345",
        check_date="2023-10-12",
    )
    """

    era_id: EraId

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
