# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .task_updated_to_deprecated_status_error import TaskUpdatedToDeprecatedStatusError

__all__ = ["TaskUpdatedToDeprecatedStatusError"]
