# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from .tag_create import TagCreate


class Tag(TagCreate):
    """
    Examples
    --------
    from candid.resources.tags import Tag, TagColorEnum

    Tag(
        creator_id="00EB5A46-35C6-441B-9751-AF307AEF5888",
        tag_id="void-claim-submitted",
        description="to indicate claims where a void claim has been submitted",
        color=TagColorEnum.BLACK,
    )
    """

    creator_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
