# This file was auto-generated by Fern from our API Definition.

import typing

from .individual_provider import IndividualProvider
from .organization_provider import OrganizationProvider

Provider = typing.Union[IndividualProvider, OrganizationProvider]
