# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class EncounterProviderBase(UniversalBaseModel):
    first_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    If the provider is an individual, this should be set instead of organization name
    """

    last_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    If the provider is an individual, this should be set instead of organization name
    """

    organization_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    If the provider is an organization, this should be set instead of first + last name
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
