# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.charge_capture_post_billed_change_id import ChargeCapturePostBilledChangeId


class ChargeCapturePostBilledChange(UniversalBaseModel):
    """
    ChargeCapturePostBilledChange represents a change to a ChargeCapture that occurred after the ChargeCapture's status moved to BILLED. Action must be taken to resolve the update, and then the update should be marked as resolved.
    """

    id: ChargeCapturePostBilledChangeId
    message: str
    resolved: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
