# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....contracts.resources.v_2.types.contract_id import ContractId
from .expected_network_status import ExpectedNetworkStatus


class ExpectedNetworkStatusResponse(UniversalBaseModel):
    expected_network_status: ExpectedNetworkStatus = pydantic.Field()
    """
    The anticipated classification of a healthcare provider within the insurance plan's network.
    """

    explanation: str
    contract_id: typing.Optional[ContractId] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
