# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Carc(str, enum.Enum):
    CARC_1 = "1"
    CARC_2 = "2"
    CARC_3 = "3"
    CARC_4 = "4"
    CARC_5 = "5"
    CARC_6 = "6"
    CARC_7 = "7"
    CARC_8 = "8"
    CARC_9 = "9"
    CARC_10 = "10"
    CARC_11 = "11"
    CARC_12 = "12"
    CARC_13 = "13"
    CARC_14 = "14"
    CARC_16 = "16"
    CARC_18 = "18"
    CARC_19 = "19"
    CARC_20 = "20"
    CARC_21 = "21"
    CARC_22 = "22"
    CARC_23 = "23"
    CARC_24 = "24"
    CARC_26 = "26"
    CARC_27 = "27"
    CARC_29 = "29"
    CARC_31 = "31"
    CARC_32 = "32"
    CARC_33 = "33"
    CARC_34 = "34"
    CARC_35 = "35"
    CARC_39 = "39"
    CARC_40 = "40"
    CARC_44 = "44"
    CARC_45 = "45"
    CARC_49 = "49"
    CARC_50 = "50"
    CARC_51 = "51"
    CARC_53 = "53"
    CARC_54 = "54"
    CARC_55 = "55"
    CARC_56 = "56"
    CARC_58 = "58"
    CARC_59 = "59"
    CARC_60 = "60"
    CARC_61 = "61"
    CARC_66 = "66"
    CARC_69 = "69"
    CARC_70 = "70"
    CARC_74 = "74"
    CARC_75 = "75"
    CARC_76 = "76"
    CARC_78 = "78"
    CARC_85 = "85"
    CARC_89 = "89"
    CARC_90 = "90"
    CARC_91 = "91"
    CARC_94 = "94"
    CARC_95 = "95"
    CARC_96 = "96"
    CARC_97 = "97"
    CARC_100 = "100"
    CARC_101 = "101"
    CARC_102 = "102"
    CARC_103 = "103"
    CARC_104 = "104"
    CARC_105 = "105"
    CARC_106 = "106"
    CARC_107 = "107"
    CARC_108 = "108"
    CARC_109 = "109"
    CARC_110 = "110"
    CARC_111 = "111"
    CARC_112 = "112"
    CARC_114 = "114"
    CARC_115 = "115"
    CARC_116 = "116"
    CARC_117 = "117"
    CARC_118 = "118"
    CARC_119 = "119"
    CARC_121 = "121"
    CARC_122 = "122"
    CARC_125 = "125"
    CARC_128 = "128"
    CARC_129 = "129"
    CARC_130 = "130"
    CARC_131 = "131"
    CARC_132 = "132"
    CARC_133 = "133"
    CARC_134 = "134"
    CARC_135 = "135"
    CARC_136 = "136"
    CARC_137 = "137"
    CARC_139 = "139"
    CARC_140 = "140"
    CARC_142 = "142"
    CARC_143 = "143"
    CARC_144 = "144"
    CARC_146 = "146"
    CARC_147 = "147"
    CARC_148 = "148"
    CARC_149 = "149"
    CARC_150 = "150"
    CARC_151 = "151"
    CARC_152 = "152"
    CARC_153 = "153"
    CARC_154 = "154"
    CARC_155 = "155"
    CARC_157 = "157"
    CARC_158 = "158"
    CARC_159 = "159"
    CARC_160 = "160"
    CARC_161 = "161"
    CARC_163 = "163"
    CARC_164 = "164"
    CARC_166 = "166"
    CARC_167 = "167"
    CARC_169 = "169"
    CARC_170 = "170"
    CARC_171 = "171"
    CARC_172 = "172"
    CARC_173 = "173"
    CARC_174 = "174"
    CARC_175 = "175"
    CARC_176 = "176"
    CARC_177 = "177"
    CARC_178 = "178"
    CARC_179 = "179"
    CARC_180 = "180"
    CARC_181 = "181"
    CARC_182 = "182"
    CARC_183 = "183"
    CARC_184 = "184"
    CARC_185 = "185"
    CARC_186 = "186"
    CARC_187 = "187"
    CARC_188 = "188"
    CARC_189 = "189"
    CARC_190 = "190"
    CARC_192 = "192"
    CARC_193 = "193"
    CARC_194 = "194"
    CARC_195 = "195"
    CARC_197 = "197"
    CARC_198 = "198"
    CARC_199 = "199"
    CARC_200 = "200"
    CARC_201 = "201"
    CARC_202 = "202"
    CARC_203 = "203"
    CARC_204 = "204"
    CARC_205 = "205"
    CARC_206 = "206"
    CARC_207 = "207"
    CARC_208 = "208"
    CARC_209 = "209"
    CARC_210 = "210"
    CARC_211 = "211"
    CARC_212 = "212"
    CARC_213 = "213"
    CARC_215 = "215"
    CARC_216 = "216"
    CARC_219 = "219"
    CARC_222 = "222"
    CARC_223 = "223"
    CARC_224 = "224"
    CARC_225 = "225"
    CARC_226 = "226"
    CARC_227 = "227"
    CARC_228 = "228"
    CARC_229 = "229"
    CARC_231 = "231"
    CARC_232 = "232"
    CARC_233 = "233"
    CARC_234 = "234"
    CARC_235 = "235"
    CARC_236 = "236"
    CARC_237 = "237"
    CARC_238 = "238"
    CARC_239 = "239"
    CARC_240 = "240"
    CARC_241 = "241"
    CARC_242 = "242"
    CARC_243 = "243"
    CARC_245 = "245"
    CARC_246 = "246"
    CARC_247 = "247"
    CARC_248 = "248"
    CARC_249 = "249"
    CARC_250 = "250"
    CARC_251 = "251"
    CARC_252 = "252"
    CARC_253 = "253"
    CARC_254 = "254"
    CARC_256 = "256"
    CARC_257 = "257"
    CARC_258 = "258"
    CARC_259 = "259"
    CARC_260 = "260"
    CARC_261 = "261"
    CARC_262 = "262"
    CARC_263 = "263"
    CARC_264 = "264"
    CARC_265 = "265"
    CARC_266 = "266"
    CARC_267 = "267"
    CARC_268 = "268"
    CARC_269 = "269"
    CARC_270 = "270"
    CARC_271 = "271"
    CARC_272 = "272"
    CARC_273 = "273"
    CARC_274 = "274"
    CARC_275 = "275"
    CARC_276 = "276"
    CARC_277 = "277"
    CARC_278 = "278"
    CARC_279 = "279"
    CARC_280 = "280"
    CARC_281 = "281"
    CARC_282 = "282"
    CARC_283 = "283"
    CARC_284 = "284"
    CARC_285 = "285"
    CARC_286 = "286"
    CARC_287 = "287"
    CARC_288 = "288"
    CARC_289 = "289"
    CARC_290 = "290"
    CARC_291 = "291"
    CARC_292 = "292"
    CARC_293 = "293"
    CARC_294 = "294"
    CARC_295 = "295"
    CARC_296 = "296"
    CARC_297 = "297"
    CARC_298 = "298"
    CARC_299 = "299"
    CARC_300 = "300"
    CARC_301 = "301"
    CARC_302 = "302"
    CARC_303 = "303"
    CARC_304 = "304"
    CARC_305 = "305"
    CARC_A_0 = "A0"
    CARC_A_1 = "A1"
    CARC_A_5 = "A5"
    CARC_A_6 = "A6"
    CARC_A_8 = "A8"
    CARC_B_1 = "B1"
    CARC_B_4 = "B4"
    CARC_B_7 = "B7"
    CARC_B_8 = "B8"
    CARC_B_9 = "B9"
    CARC_B_10 = "B10"
    CARC_B_11 = "B11"
    CARC_B_12 = "B12"
    CARC_B_13 = "B13"
    CARC_B_14 = "B14"
    CARC_B_15 = "B15"
    CARC_B_16 = "B16"
    CARC_B_20 = "B20"
    CARC_B_22 = "B22"
    CARC_B_23 = "B23"
    CARC_P_1 = "P1"
    CARC_P_2 = "P2"
    CARC_P_3 = "P3"
    CARC_P_4 = "P4"
    CARC_P_5 = "P5"
    CARC_P_6 = "P6"
    CARC_P_7 = "P7"
    CARC_P_8 = "P8"
    CARC_P_9 = "P9"
    CARC_P_10 = "P10"
    CARC_P_11 = "P11"
    CARC_P_12 = "P12"
    CARC_P_13 = "P13"
    CARC_P_14 = "P14"
    CARC_P_15 = "P15"
    CARC_P_16 = "P16"
    CARC_P_17 = "P17"
    CARC_P_18 = "P18"
    CARC_P_19 = "P19"
    CARC_P_20 = "P20"
    CARC_P_21 = "P21"
    CARC_P_22 = "P22"
    CARC_P_23 = "P23"
    CARC_P_24 = "P24"
    CARC_P_25 = "P25"
    CARC_P_26 = "P26"
    CARC_P_27 = "P27"
    CARC_P_28 = "P28"
    CARC_P_29 = "P29"
    CARC_P_30 = "P30"
    CARC_P_31 = "P31"
    CARC_P_32 = "P32"
    CARC_17 = "17"
    CARC_25 = "25"
    CARC_28 = "28"
    CARC_30 = "30"
    CARC_36 = "36"
    CARC_37 = "37"
    CARC_38 = "38"
    CARC_41 = "41"
    CARC_42 = "42"
    CARC_43 = "43"
    CARC_46 = "46"
    CARC_47 = "47"
    CARC_48 = "48"
    CARC_52 = "52"
    CARC_57 = "57"
    CARC_62 = "62"
    CARC_63 = "63"
    CARC_64 = "64"
    CARC_65 = "65"
    CARC_67 = "67"
    CARC_68 = "68"
    CARC_71 = "71"
    CARC_72 = "72"
    CARC_73 = "73"
    CARC_77 = "77"
    CARC_79 = "79"
    CARC_80 = "80"
    CARC_81 = "81"
    CARC_82 = "82"
    CARC_83 = "83"
    CARC_84 = "84"
    CARC_86 = "86"
    CARC_87 = "87"
    CARC_88 = "88"
    CARC_92 = "92"
    CARC_93 = "93"
    CARC_98 = "98"
    CARC_99 = "99"
    CARC_113 = "113"
    CARC_120 = "120"
    CARC_123 = "123"
    CARC_124 = "124"
    CARC_126 = "126"
    CARC_127 = "127"
    CARC_138 = "138"
    CARC_141 = "141"
    CARC_145 = "145"
    CARC_156 = "156"
    CARC_162 = "162"
    CARC_165 = "165"
    CARC_168 = "168"
    CARC_191 = "191"
    CARC_196 = "196"
    CARC_214 = "214"
    CARC_217 = "217"
    CARC_218 = "218"
    CARC_220 = "220"
    CARC_221 = "221"
    CARC_230 = "230"
    CARC_244 = "244"
    CARC_255 = "255"
    CARC_A_2 = "A2"
    CARC_A_3 = "A3"
    CARC_A_4 = "A4"
    CARC_A_7 = "A7"
    CARC_B_2 = "B2"
    CARC_B_3 = "B3"
    CARC_B_5 = "B5"
    CARC_B_6 = "B6"
    CARC_B_17 = "B17"
    CARC_B_18 = "B18"
    CARC_B_19 = "B19"
    CARC_B_21 = "B21"
    CARC_D_1 = "D1"
    CARC_D_2 = "D2"
    CARC_D_3 = "D3"
    CARC_D_4 = "D4"
    CARC_D_5 = "D5"
    CARC_D_6 = "D6"
    CARC_D_7 = "D7"
    CARC_D_8 = "D8"
    CARC_D_9 = "D9"
    CARC_D_10 = "D10"
    CARC_D_11 = "D11"
    CARC_D_12 = "D12"
    CARC_D_14 = "D14"
    CARC_D_15 = "D15"
    CARC_D_16 = "D16"
    CARC_D_17 = "D17"
    CARC_D_18 = "D18"
    CARC_D_19 = "D19"
    CARC_D_20 = "D20"
    CARC_D_21 = "D21"
    CARC_D_22 = "D22"
    CARC_D_23 = "D23"
    CARC_W_1 = "W1"
    CARC_W_2 = "W2"
    CARC_W_3 = "W3"
    CARC_W_4 = "W4"
    CARC_W_5 = "W5"
    CARC_W_6 = "W6"
    CARC_W_7 = "W7"
    CARC_W_8 = "W8"
    CARC_W_9 = "W9"
    CARC_Y_1 = "Y1"
    CARC_Y_2 = "Y2"
    CARC_Y_3 = "Y3"
    UNKNOWN = "UNKNOWN"
    _UNKNOWN = "__CARC_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "Carc":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        carc_1: typing.Callable[[], T_Result],
        carc_2: typing.Callable[[], T_Result],
        carc_3: typing.Callable[[], T_Result],
        carc_4: typing.Callable[[], T_Result],
        carc_5: typing.Callable[[], T_Result],
        carc_6: typing.Callable[[], T_Result],
        carc_7: typing.Callable[[], T_Result],
        carc_8: typing.Callable[[], T_Result],
        carc_9: typing.Callable[[], T_Result],
        carc_10: typing.Callable[[], T_Result],
        carc_11: typing.Callable[[], T_Result],
        carc_12: typing.Callable[[], T_Result],
        carc_13: typing.Callable[[], T_Result],
        carc_14: typing.Callable[[], T_Result],
        carc_16: typing.Callable[[], T_Result],
        carc_18: typing.Callable[[], T_Result],
        carc_19: typing.Callable[[], T_Result],
        carc_20: typing.Callable[[], T_Result],
        carc_21: typing.Callable[[], T_Result],
        carc_22: typing.Callable[[], T_Result],
        carc_23: typing.Callable[[], T_Result],
        carc_24: typing.Callable[[], T_Result],
        carc_26: typing.Callable[[], T_Result],
        carc_27: typing.Callable[[], T_Result],
        carc_29: typing.Callable[[], T_Result],
        carc_31: typing.Callable[[], T_Result],
        carc_32: typing.Callable[[], T_Result],
        carc_33: typing.Callable[[], T_Result],
        carc_34: typing.Callable[[], T_Result],
        carc_35: typing.Callable[[], T_Result],
        carc_39: typing.Callable[[], T_Result],
        carc_40: typing.Callable[[], T_Result],
        carc_44: typing.Callable[[], T_Result],
        carc_45: typing.Callable[[], T_Result],
        carc_49: typing.Callable[[], T_Result],
        carc_50: typing.Callable[[], T_Result],
        carc_51: typing.Callable[[], T_Result],
        carc_53: typing.Callable[[], T_Result],
        carc_54: typing.Callable[[], T_Result],
        carc_55: typing.Callable[[], T_Result],
        carc_56: typing.Callable[[], T_Result],
        carc_58: typing.Callable[[], T_Result],
        carc_59: typing.Callable[[], T_Result],
        carc_60: typing.Callable[[], T_Result],
        carc_61: typing.Callable[[], T_Result],
        carc_66: typing.Callable[[], T_Result],
        carc_69: typing.Callable[[], T_Result],
        carc_70: typing.Callable[[], T_Result],
        carc_74: typing.Callable[[], T_Result],
        carc_75: typing.Callable[[], T_Result],
        carc_76: typing.Callable[[], T_Result],
        carc_78: typing.Callable[[], T_Result],
        carc_85: typing.Callable[[], T_Result],
        carc_89: typing.Callable[[], T_Result],
        carc_90: typing.Callable[[], T_Result],
        carc_91: typing.Callable[[], T_Result],
        carc_94: typing.Callable[[], T_Result],
        carc_95: typing.Callable[[], T_Result],
        carc_96: typing.Callable[[], T_Result],
        carc_97: typing.Callable[[], T_Result],
        carc_100: typing.Callable[[], T_Result],
        carc_101: typing.Callable[[], T_Result],
        carc_102: typing.Callable[[], T_Result],
        carc_103: typing.Callable[[], T_Result],
        carc_104: typing.Callable[[], T_Result],
        carc_105: typing.Callable[[], T_Result],
        carc_106: typing.Callable[[], T_Result],
        carc_107: typing.Callable[[], T_Result],
        carc_108: typing.Callable[[], T_Result],
        carc_109: typing.Callable[[], T_Result],
        carc_110: typing.Callable[[], T_Result],
        carc_111: typing.Callable[[], T_Result],
        carc_112: typing.Callable[[], T_Result],
        carc_114: typing.Callable[[], T_Result],
        carc_115: typing.Callable[[], T_Result],
        carc_116: typing.Callable[[], T_Result],
        carc_117: typing.Callable[[], T_Result],
        carc_118: typing.Callable[[], T_Result],
        carc_119: typing.Callable[[], T_Result],
        carc_121: typing.Callable[[], T_Result],
        carc_122: typing.Callable[[], T_Result],
        carc_125: typing.Callable[[], T_Result],
        carc_128: typing.Callable[[], T_Result],
        carc_129: typing.Callable[[], T_Result],
        carc_130: typing.Callable[[], T_Result],
        carc_131: typing.Callable[[], T_Result],
        carc_132: typing.Callable[[], T_Result],
        carc_133: typing.Callable[[], T_Result],
        carc_134: typing.Callable[[], T_Result],
        carc_135: typing.Callable[[], T_Result],
        carc_136: typing.Callable[[], T_Result],
        carc_137: typing.Callable[[], T_Result],
        carc_139: typing.Callable[[], T_Result],
        carc_140: typing.Callable[[], T_Result],
        carc_142: typing.Callable[[], T_Result],
        carc_143: typing.Callable[[], T_Result],
        carc_144: typing.Callable[[], T_Result],
        carc_146: typing.Callable[[], T_Result],
        carc_147: typing.Callable[[], T_Result],
        carc_148: typing.Callable[[], T_Result],
        carc_149: typing.Callable[[], T_Result],
        carc_150: typing.Callable[[], T_Result],
        carc_151: typing.Callable[[], T_Result],
        carc_152: typing.Callable[[], T_Result],
        carc_153: typing.Callable[[], T_Result],
        carc_154: typing.Callable[[], T_Result],
        carc_155: typing.Callable[[], T_Result],
        carc_157: typing.Callable[[], T_Result],
        carc_158: typing.Callable[[], T_Result],
        carc_159: typing.Callable[[], T_Result],
        carc_160: typing.Callable[[], T_Result],
        carc_161: typing.Callable[[], T_Result],
        carc_163: typing.Callable[[], T_Result],
        carc_164: typing.Callable[[], T_Result],
        carc_166: typing.Callable[[], T_Result],
        carc_167: typing.Callable[[], T_Result],
        carc_169: typing.Callable[[], T_Result],
        carc_170: typing.Callable[[], T_Result],
        carc_171: typing.Callable[[], T_Result],
        carc_172: typing.Callable[[], T_Result],
        carc_173: typing.Callable[[], T_Result],
        carc_174: typing.Callable[[], T_Result],
        carc_175: typing.Callable[[], T_Result],
        carc_176: typing.Callable[[], T_Result],
        carc_177: typing.Callable[[], T_Result],
        carc_178: typing.Callable[[], T_Result],
        carc_179: typing.Callable[[], T_Result],
        carc_180: typing.Callable[[], T_Result],
        carc_181: typing.Callable[[], T_Result],
        carc_182: typing.Callable[[], T_Result],
        carc_183: typing.Callable[[], T_Result],
        carc_184: typing.Callable[[], T_Result],
        carc_185: typing.Callable[[], T_Result],
        carc_186: typing.Callable[[], T_Result],
        carc_187: typing.Callable[[], T_Result],
        carc_188: typing.Callable[[], T_Result],
        carc_189: typing.Callable[[], T_Result],
        carc_190: typing.Callable[[], T_Result],
        carc_192: typing.Callable[[], T_Result],
        carc_193: typing.Callable[[], T_Result],
        carc_194: typing.Callable[[], T_Result],
        carc_195: typing.Callable[[], T_Result],
        carc_197: typing.Callable[[], T_Result],
        carc_198: typing.Callable[[], T_Result],
        carc_199: typing.Callable[[], T_Result],
        carc_200: typing.Callable[[], T_Result],
        carc_201: typing.Callable[[], T_Result],
        carc_202: typing.Callable[[], T_Result],
        carc_203: typing.Callable[[], T_Result],
        carc_204: typing.Callable[[], T_Result],
        carc_205: typing.Callable[[], T_Result],
        carc_206: typing.Callable[[], T_Result],
        carc_207: typing.Callable[[], T_Result],
        carc_208: typing.Callable[[], T_Result],
        carc_209: typing.Callable[[], T_Result],
        carc_210: typing.Callable[[], T_Result],
        carc_211: typing.Callable[[], T_Result],
        carc_212: typing.Callable[[], T_Result],
        carc_213: typing.Callable[[], T_Result],
        carc_215: typing.Callable[[], T_Result],
        carc_216: typing.Callable[[], T_Result],
        carc_219: typing.Callable[[], T_Result],
        carc_222: typing.Callable[[], T_Result],
        carc_223: typing.Callable[[], T_Result],
        carc_224: typing.Callable[[], T_Result],
        carc_225: typing.Callable[[], T_Result],
        carc_226: typing.Callable[[], T_Result],
        carc_227: typing.Callable[[], T_Result],
        carc_228: typing.Callable[[], T_Result],
        carc_229: typing.Callable[[], T_Result],
        carc_231: typing.Callable[[], T_Result],
        carc_232: typing.Callable[[], T_Result],
        carc_233: typing.Callable[[], T_Result],
        carc_234: typing.Callable[[], T_Result],
        carc_235: typing.Callable[[], T_Result],
        carc_236: typing.Callable[[], T_Result],
        carc_237: typing.Callable[[], T_Result],
        carc_238: typing.Callable[[], T_Result],
        carc_239: typing.Callable[[], T_Result],
        carc_240: typing.Callable[[], T_Result],
        carc_241: typing.Callable[[], T_Result],
        carc_242: typing.Callable[[], T_Result],
        carc_243: typing.Callable[[], T_Result],
        carc_245: typing.Callable[[], T_Result],
        carc_246: typing.Callable[[], T_Result],
        carc_247: typing.Callable[[], T_Result],
        carc_248: typing.Callable[[], T_Result],
        carc_249: typing.Callable[[], T_Result],
        carc_250: typing.Callable[[], T_Result],
        carc_251: typing.Callable[[], T_Result],
        carc_252: typing.Callable[[], T_Result],
        carc_253: typing.Callable[[], T_Result],
        carc_254: typing.Callable[[], T_Result],
        carc_256: typing.Callable[[], T_Result],
        carc_257: typing.Callable[[], T_Result],
        carc_258: typing.Callable[[], T_Result],
        carc_259: typing.Callable[[], T_Result],
        carc_260: typing.Callable[[], T_Result],
        carc_261: typing.Callable[[], T_Result],
        carc_262: typing.Callable[[], T_Result],
        carc_263: typing.Callable[[], T_Result],
        carc_264: typing.Callable[[], T_Result],
        carc_265: typing.Callable[[], T_Result],
        carc_266: typing.Callable[[], T_Result],
        carc_267: typing.Callable[[], T_Result],
        carc_268: typing.Callable[[], T_Result],
        carc_269: typing.Callable[[], T_Result],
        carc_270: typing.Callable[[], T_Result],
        carc_271: typing.Callable[[], T_Result],
        carc_272: typing.Callable[[], T_Result],
        carc_273: typing.Callable[[], T_Result],
        carc_274: typing.Callable[[], T_Result],
        carc_275: typing.Callable[[], T_Result],
        carc_276: typing.Callable[[], T_Result],
        carc_277: typing.Callable[[], T_Result],
        carc_278: typing.Callable[[], T_Result],
        carc_279: typing.Callable[[], T_Result],
        carc_280: typing.Callable[[], T_Result],
        carc_281: typing.Callable[[], T_Result],
        carc_282: typing.Callable[[], T_Result],
        carc_283: typing.Callable[[], T_Result],
        carc_284: typing.Callable[[], T_Result],
        carc_285: typing.Callable[[], T_Result],
        carc_286: typing.Callable[[], T_Result],
        carc_287: typing.Callable[[], T_Result],
        carc_288: typing.Callable[[], T_Result],
        carc_289: typing.Callable[[], T_Result],
        carc_290: typing.Callable[[], T_Result],
        carc_291: typing.Callable[[], T_Result],
        carc_292: typing.Callable[[], T_Result],
        carc_293: typing.Callable[[], T_Result],
        carc_294: typing.Callable[[], T_Result],
        carc_295: typing.Callable[[], T_Result],
        carc_296: typing.Callable[[], T_Result],
        carc_297: typing.Callable[[], T_Result],
        carc_298: typing.Callable[[], T_Result],
        carc_299: typing.Callable[[], T_Result],
        carc_300: typing.Callable[[], T_Result],
        carc_301: typing.Callable[[], T_Result],
        carc_302: typing.Callable[[], T_Result],
        carc_303: typing.Callable[[], T_Result],
        carc_304: typing.Callable[[], T_Result],
        carc_305: typing.Callable[[], T_Result],
        carc_a_0: typing.Callable[[], T_Result],
        carc_a_1: typing.Callable[[], T_Result],
        carc_a_5: typing.Callable[[], T_Result],
        carc_a_6: typing.Callable[[], T_Result],
        carc_a_8: typing.Callable[[], T_Result],
        carc_b_1: typing.Callable[[], T_Result],
        carc_b_4: typing.Callable[[], T_Result],
        carc_b_7: typing.Callable[[], T_Result],
        carc_b_8: typing.Callable[[], T_Result],
        carc_b_9: typing.Callable[[], T_Result],
        carc_b_10: typing.Callable[[], T_Result],
        carc_b_11: typing.Callable[[], T_Result],
        carc_b_12: typing.Callable[[], T_Result],
        carc_b_13: typing.Callable[[], T_Result],
        carc_b_14: typing.Callable[[], T_Result],
        carc_b_15: typing.Callable[[], T_Result],
        carc_b_16: typing.Callable[[], T_Result],
        carc_b_20: typing.Callable[[], T_Result],
        carc_b_22: typing.Callable[[], T_Result],
        carc_b_23: typing.Callable[[], T_Result],
        carc_p_1: typing.Callable[[], T_Result],
        carc_p_2: typing.Callable[[], T_Result],
        carc_p_3: typing.Callable[[], T_Result],
        carc_p_4: typing.Callable[[], T_Result],
        carc_p_5: typing.Callable[[], T_Result],
        carc_p_6: typing.Callable[[], T_Result],
        carc_p_7: typing.Callable[[], T_Result],
        carc_p_8: typing.Callable[[], T_Result],
        carc_p_9: typing.Callable[[], T_Result],
        carc_p_10: typing.Callable[[], T_Result],
        carc_p_11: typing.Callable[[], T_Result],
        carc_p_12: typing.Callable[[], T_Result],
        carc_p_13: typing.Callable[[], T_Result],
        carc_p_14: typing.Callable[[], T_Result],
        carc_p_15: typing.Callable[[], T_Result],
        carc_p_16: typing.Callable[[], T_Result],
        carc_p_17: typing.Callable[[], T_Result],
        carc_p_18: typing.Callable[[], T_Result],
        carc_p_19: typing.Callable[[], T_Result],
        carc_p_20: typing.Callable[[], T_Result],
        carc_p_21: typing.Callable[[], T_Result],
        carc_p_22: typing.Callable[[], T_Result],
        carc_p_23: typing.Callable[[], T_Result],
        carc_p_24: typing.Callable[[], T_Result],
        carc_p_25: typing.Callable[[], T_Result],
        carc_p_26: typing.Callable[[], T_Result],
        carc_p_27: typing.Callable[[], T_Result],
        carc_p_28: typing.Callable[[], T_Result],
        carc_p_29: typing.Callable[[], T_Result],
        carc_p_30: typing.Callable[[], T_Result],
        carc_p_31: typing.Callable[[], T_Result],
        carc_p_32: typing.Callable[[], T_Result],
        carc_17: typing.Callable[[], T_Result],
        carc_25: typing.Callable[[], T_Result],
        carc_28: typing.Callable[[], T_Result],
        carc_30: typing.Callable[[], T_Result],
        carc_36: typing.Callable[[], T_Result],
        carc_37: typing.Callable[[], T_Result],
        carc_38: typing.Callable[[], T_Result],
        carc_41: typing.Callable[[], T_Result],
        carc_42: typing.Callable[[], T_Result],
        carc_43: typing.Callable[[], T_Result],
        carc_46: typing.Callable[[], T_Result],
        carc_47: typing.Callable[[], T_Result],
        carc_48: typing.Callable[[], T_Result],
        carc_52: typing.Callable[[], T_Result],
        carc_57: typing.Callable[[], T_Result],
        carc_62: typing.Callable[[], T_Result],
        carc_63: typing.Callable[[], T_Result],
        carc_64: typing.Callable[[], T_Result],
        carc_65: typing.Callable[[], T_Result],
        carc_67: typing.Callable[[], T_Result],
        carc_68: typing.Callable[[], T_Result],
        carc_71: typing.Callable[[], T_Result],
        carc_72: typing.Callable[[], T_Result],
        carc_73: typing.Callable[[], T_Result],
        carc_77: typing.Callable[[], T_Result],
        carc_79: typing.Callable[[], T_Result],
        carc_80: typing.Callable[[], T_Result],
        carc_81: typing.Callable[[], T_Result],
        carc_82: typing.Callable[[], T_Result],
        carc_83: typing.Callable[[], T_Result],
        carc_84: typing.Callable[[], T_Result],
        carc_86: typing.Callable[[], T_Result],
        carc_87: typing.Callable[[], T_Result],
        carc_88: typing.Callable[[], T_Result],
        carc_92: typing.Callable[[], T_Result],
        carc_93: typing.Callable[[], T_Result],
        carc_98: typing.Callable[[], T_Result],
        carc_99: typing.Callable[[], T_Result],
        carc_113: typing.Callable[[], T_Result],
        carc_120: typing.Callable[[], T_Result],
        carc_123: typing.Callable[[], T_Result],
        carc_124: typing.Callable[[], T_Result],
        carc_126: typing.Callable[[], T_Result],
        carc_127: typing.Callable[[], T_Result],
        carc_138: typing.Callable[[], T_Result],
        carc_141: typing.Callable[[], T_Result],
        carc_145: typing.Callable[[], T_Result],
        carc_156: typing.Callable[[], T_Result],
        carc_162: typing.Callable[[], T_Result],
        carc_165: typing.Callable[[], T_Result],
        carc_168: typing.Callable[[], T_Result],
        carc_191: typing.Callable[[], T_Result],
        carc_196: typing.Callable[[], T_Result],
        carc_214: typing.Callable[[], T_Result],
        carc_217: typing.Callable[[], T_Result],
        carc_218: typing.Callable[[], T_Result],
        carc_220: typing.Callable[[], T_Result],
        carc_221: typing.Callable[[], T_Result],
        carc_230: typing.Callable[[], T_Result],
        carc_244: typing.Callable[[], T_Result],
        carc_255: typing.Callable[[], T_Result],
        carc_a_2: typing.Callable[[], T_Result],
        carc_a_3: typing.Callable[[], T_Result],
        carc_a_4: typing.Callable[[], T_Result],
        carc_a_7: typing.Callable[[], T_Result],
        carc_b_2: typing.Callable[[], T_Result],
        carc_b_3: typing.Callable[[], T_Result],
        carc_b_5: typing.Callable[[], T_Result],
        carc_b_6: typing.Callable[[], T_Result],
        carc_b_17: typing.Callable[[], T_Result],
        carc_b_18: typing.Callable[[], T_Result],
        carc_b_19: typing.Callable[[], T_Result],
        carc_b_21: typing.Callable[[], T_Result],
        carc_d_1: typing.Callable[[], T_Result],
        carc_d_2: typing.Callable[[], T_Result],
        carc_d_3: typing.Callable[[], T_Result],
        carc_d_4: typing.Callable[[], T_Result],
        carc_d_5: typing.Callable[[], T_Result],
        carc_d_6: typing.Callable[[], T_Result],
        carc_d_7: typing.Callable[[], T_Result],
        carc_d_8: typing.Callable[[], T_Result],
        carc_d_9: typing.Callable[[], T_Result],
        carc_d_10: typing.Callable[[], T_Result],
        carc_d_11: typing.Callable[[], T_Result],
        carc_d_12: typing.Callable[[], T_Result],
        carc_d_14: typing.Callable[[], T_Result],
        carc_d_15: typing.Callable[[], T_Result],
        carc_d_16: typing.Callable[[], T_Result],
        carc_d_17: typing.Callable[[], T_Result],
        carc_d_18: typing.Callable[[], T_Result],
        carc_d_19: typing.Callable[[], T_Result],
        carc_d_20: typing.Callable[[], T_Result],
        carc_d_21: typing.Callable[[], T_Result],
        carc_d_22: typing.Callable[[], T_Result],
        carc_d_23: typing.Callable[[], T_Result],
        carc_w_1: typing.Callable[[], T_Result],
        carc_w_2: typing.Callable[[], T_Result],
        carc_w_3: typing.Callable[[], T_Result],
        carc_w_4: typing.Callable[[], T_Result],
        carc_w_5: typing.Callable[[], T_Result],
        carc_w_6: typing.Callable[[], T_Result],
        carc_w_7: typing.Callable[[], T_Result],
        carc_w_8: typing.Callable[[], T_Result],
        carc_w_9: typing.Callable[[], T_Result],
        carc_y_1: typing.Callable[[], T_Result],
        carc_y_2: typing.Callable[[], T_Result],
        carc_y_3: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is Carc.CARC_1:
            return carc_1()
        if self is Carc.CARC_2:
            return carc_2()
        if self is Carc.CARC_3:
            return carc_3()
        if self is Carc.CARC_4:
            return carc_4()
        if self is Carc.CARC_5:
            return carc_5()
        if self is Carc.CARC_6:
            return carc_6()
        if self is Carc.CARC_7:
            return carc_7()
        if self is Carc.CARC_8:
            return carc_8()
        if self is Carc.CARC_9:
            return carc_9()
        if self is Carc.CARC_10:
            return carc_10()
        if self is Carc.CARC_11:
            return carc_11()
        if self is Carc.CARC_12:
            return carc_12()
        if self is Carc.CARC_13:
            return carc_13()
        if self is Carc.CARC_14:
            return carc_14()
        if self is Carc.CARC_16:
            return carc_16()
        if self is Carc.CARC_18:
            return carc_18()
        if self is Carc.CARC_19:
            return carc_19()
        if self is Carc.CARC_20:
            return carc_20()
        if self is Carc.CARC_21:
            return carc_21()
        if self is Carc.CARC_22:
            return carc_22()
        if self is Carc.CARC_23:
            return carc_23()
        if self is Carc.CARC_24:
            return carc_24()
        if self is Carc.CARC_26:
            return carc_26()
        if self is Carc.CARC_27:
            return carc_27()
        if self is Carc.CARC_29:
            return carc_29()
        if self is Carc.CARC_31:
            return carc_31()
        if self is Carc.CARC_32:
            return carc_32()
        if self is Carc.CARC_33:
            return carc_33()
        if self is Carc.CARC_34:
            return carc_34()
        if self is Carc.CARC_35:
            return carc_35()
        if self is Carc.CARC_39:
            return carc_39()
        if self is Carc.CARC_40:
            return carc_40()
        if self is Carc.CARC_44:
            return carc_44()
        if self is Carc.CARC_45:
            return carc_45()
        if self is Carc.CARC_49:
            return carc_49()
        if self is Carc.CARC_50:
            return carc_50()
        if self is Carc.CARC_51:
            return carc_51()
        if self is Carc.CARC_53:
            return carc_53()
        if self is Carc.CARC_54:
            return carc_54()
        if self is Carc.CARC_55:
            return carc_55()
        if self is Carc.CARC_56:
            return carc_56()
        if self is Carc.CARC_58:
            return carc_58()
        if self is Carc.CARC_59:
            return carc_59()
        if self is Carc.CARC_60:
            return carc_60()
        if self is Carc.CARC_61:
            return carc_61()
        if self is Carc.CARC_66:
            return carc_66()
        if self is Carc.CARC_69:
            return carc_69()
        if self is Carc.CARC_70:
            return carc_70()
        if self is Carc.CARC_74:
            return carc_74()
        if self is Carc.CARC_75:
            return carc_75()
        if self is Carc.CARC_76:
            return carc_76()
        if self is Carc.CARC_78:
            return carc_78()
        if self is Carc.CARC_85:
            return carc_85()
        if self is Carc.CARC_89:
            return carc_89()
        if self is Carc.CARC_90:
            return carc_90()
        if self is Carc.CARC_91:
            return carc_91()
        if self is Carc.CARC_94:
            return carc_94()
        if self is Carc.CARC_95:
            return carc_95()
        if self is Carc.CARC_96:
            return carc_96()
        if self is Carc.CARC_97:
            return carc_97()
        if self is Carc.CARC_100:
            return carc_100()
        if self is Carc.CARC_101:
            return carc_101()
        if self is Carc.CARC_102:
            return carc_102()
        if self is Carc.CARC_103:
            return carc_103()
        if self is Carc.CARC_104:
            return carc_104()
        if self is Carc.CARC_105:
            return carc_105()
        if self is Carc.CARC_106:
            return carc_106()
        if self is Carc.CARC_107:
            return carc_107()
        if self is Carc.CARC_108:
            return carc_108()
        if self is Carc.CARC_109:
            return carc_109()
        if self is Carc.CARC_110:
            return carc_110()
        if self is Carc.CARC_111:
            return carc_111()
        if self is Carc.CARC_112:
            return carc_112()
        if self is Carc.CARC_114:
            return carc_114()
        if self is Carc.CARC_115:
            return carc_115()
        if self is Carc.CARC_116:
            return carc_116()
        if self is Carc.CARC_117:
            return carc_117()
        if self is Carc.CARC_118:
            return carc_118()
        if self is Carc.CARC_119:
            return carc_119()
        if self is Carc.CARC_121:
            return carc_121()
        if self is Carc.CARC_122:
            return carc_122()
        if self is Carc.CARC_125:
            return carc_125()
        if self is Carc.CARC_128:
            return carc_128()
        if self is Carc.CARC_129:
            return carc_129()
        if self is Carc.CARC_130:
            return carc_130()
        if self is Carc.CARC_131:
            return carc_131()
        if self is Carc.CARC_132:
            return carc_132()
        if self is Carc.CARC_133:
            return carc_133()
        if self is Carc.CARC_134:
            return carc_134()
        if self is Carc.CARC_135:
            return carc_135()
        if self is Carc.CARC_136:
            return carc_136()
        if self is Carc.CARC_137:
            return carc_137()
        if self is Carc.CARC_139:
            return carc_139()
        if self is Carc.CARC_140:
            return carc_140()
        if self is Carc.CARC_142:
            return carc_142()
        if self is Carc.CARC_143:
            return carc_143()
        if self is Carc.CARC_144:
            return carc_144()
        if self is Carc.CARC_146:
            return carc_146()
        if self is Carc.CARC_147:
            return carc_147()
        if self is Carc.CARC_148:
            return carc_148()
        if self is Carc.CARC_149:
            return carc_149()
        if self is Carc.CARC_150:
            return carc_150()
        if self is Carc.CARC_151:
            return carc_151()
        if self is Carc.CARC_152:
            return carc_152()
        if self is Carc.CARC_153:
            return carc_153()
        if self is Carc.CARC_154:
            return carc_154()
        if self is Carc.CARC_155:
            return carc_155()
        if self is Carc.CARC_157:
            return carc_157()
        if self is Carc.CARC_158:
            return carc_158()
        if self is Carc.CARC_159:
            return carc_159()
        if self is Carc.CARC_160:
            return carc_160()
        if self is Carc.CARC_161:
            return carc_161()
        if self is Carc.CARC_163:
            return carc_163()
        if self is Carc.CARC_164:
            return carc_164()
        if self is Carc.CARC_166:
            return carc_166()
        if self is Carc.CARC_167:
            return carc_167()
        if self is Carc.CARC_169:
            return carc_169()
        if self is Carc.CARC_170:
            return carc_170()
        if self is Carc.CARC_171:
            return carc_171()
        if self is Carc.CARC_172:
            return carc_172()
        if self is Carc.CARC_173:
            return carc_173()
        if self is Carc.CARC_174:
            return carc_174()
        if self is Carc.CARC_175:
            return carc_175()
        if self is Carc.CARC_176:
            return carc_176()
        if self is Carc.CARC_177:
            return carc_177()
        if self is Carc.CARC_178:
            return carc_178()
        if self is Carc.CARC_179:
            return carc_179()
        if self is Carc.CARC_180:
            return carc_180()
        if self is Carc.CARC_181:
            return carc_181()
        if self is Carc.CARC_182:
            return carc_182()
        if self is Carc.CARC_183:
            return carc_183()
        if self is Carc.CARC_184:
            return carc_184()
        if self is Carc.CARC_185:
            return carc_185()
        if self is Carc.CARC_186:
            return carc_186()
        if self is Carc.CARC_187:
            return carc_187()
        if self is Carc.CARC_188:
            return carc_188()
        if self is Carc.CARC_189:
            return carc_189()
        if self is Carc.CARC_190:
            return carc_190()
        if self is Carc.CARC_192:
            return carc_192()
        if self is Carc.CARC_193:
            return carc_193()
        if self is Carc.CARC_194:
            return carc_194()
        if self is Carc.CARC_195:
            return carc_195()
        if self is Carc.CARC_197:
            return carc_197()
        if self is Carc.CARC_198:
            return carc_198()
        if self is Carc.CARC_199:
            return carc_199()
        if self is Carc.CARC_200:
            return carc_200()
        if self is Carc.CARC_201:
            return carc_201()
        if self is Carc.CARC_202:
            return carc_202()
        if self is Carc.CARC_203:
            return carc_203()
        if self is Carc.CARC_204:
            return carc_204()
        if self is Carc.CARC_205:
            return carc_205()
        if self is Carc.CARC_206:
            return carc_206()
        if self is Carc.CARC_207:
            return carc_207()
        if self is Carc.CARC_208:
            return carc_208()
        if self is Carc.CARC_209:
            return carc_209()
        if self is Carc.CARC_210:
            return carc_210()
        if self is Carc.CARC_211:
            return carc_211()
        if self is Carc.CARC_212:
            return carc_212()
        if self is Carc.CARC_213:
            return carc_213()
        if self is Carc.CARC_215:
            return carc_215()
        if self is Carc.CARC_216:
            return carc_216()
        if self is Carc.CARC_219:
            return carc_219()
        if self is Carc.CARC_222:
            return carc_222()
        if self is Carc.CARC_223:
            return carc_223()
        if self is Carc.CARC_224:
            return carc_224()
        if self is Carc.CARC_225:
            return carc_225()
        if self is Carc.CARC_226:
            return carc_226()
        if self is Carc.CARC_227:
            return carc_227()
        if self is Carc.CARC_228:
            return carc_228()
        if self is Carc.CARC_229:
            return carc_229()
        if self is Carc.CARC_231:
            return carc_231()
        if self is Carc.CARC_232:
            return carc_232()
        if self is Carc.CARC_233:
            return carc_233()
        if self is Carc.CARC_234:
            return carc_234()
        if self is Carc.CARC_235:
            return carc_235()
        if self is Carc.CARC_236:
            return carc_236()
        if self is Carc.CARC_237:
            return carc_237()
        if self is Carc.CARC_238:
            return carc_238()
        if self is Carc.CARC_239:
            return carc_239()
        if self is Carc.CARC_240:
            return carc_240()
        if self is Carc.CARC_241:
            return carc_241()
        if self is Carc.CARC_242:
            return carc_242()
        if self is Carc.CARC_243:
            return carc_243()
        if self is Carc.CARC_245:
            return carc_245()
        if self is Carc.CARC_246:
            return carc_246()
        if self is Carc.CARC_247:
            return carc_247()
        if self is Carc.CARC_248:
            return carc_248()
        if self is Carc.CARC_249:
            return carc_249()
        if self is Carc.CARC_250:
            return carc_250()
        if self is Carc.CARC_251:
            return carc_251()
        if self is Carc.CARC_252:
            return carc_252()
        if self is Carc.CARC_253:
            return carc_253()
        if self is Carc.CARC_254:
            return carc_254()
        if self is Carc.CARC_256:
            return carc_256()
        if self is Carc.CARC_257:
            return carc_257()
        if self is Carc.CARC_258:
            return carc_258()
        if self is Carc.CARC_259:
            return carc_259()
        if self is Carc.CARC_260:
            return carc_260()
        if self is Carc.CARC_261:
            return carc_261()
        if self is Carc.CARC_262:
            return carc_262()
        if self is Carc.CARC_263:
            return carc_263()
        if self is Carc.CARC_264:
            return carc_264()
        if self is Carc.CARC_265:
            return carc_265()
        if self is Carc.CARC_266:
            return carc_266()
        if self is Carc.CARC_267:
            return carc_267()
        if self is Carc.CARC_268:
            return carc_268()
        if self is Carc.CARC_269:
            return carc_269()
        if self is Carc.CARC_270:
            return carc_270()
        if self is Carc.CARC_271:
            return carc_271()
        if self is Carc.CARC_272:
            return carc_272()
        if self is Carc.CARC_273:
            return carc_273()
        if self is Carc.CARC_274:
            return carc_274()
        if self is Carc.CARC_275:
            return carc_275()
        if self is Carc.CARC_276:
            return carc_276()
        if self is Carc.CARC_277:
            return carc_277()
        if self is Carc.CARC_278:
            return carc_278()
        if self is Carc.CARC_279:
            return carc_279()
        if self is Carc.CARC_280:
            return carc_280()
        if self is Carc.CARC_281:
            return carc_281()
        if self is Carc.CARC_282:
            return carc_282()
        if self is Carc.CARC_283:
            return carc_283()
        if self is Carc.CARC_284:
            return carc_284()
        if self is Carc.CARC_285:
            return carc_285()
        if self is Carc.CARC_286:
            return carc_286()
        if self is Carc.CARC_287:
            return carc_287()
        if self is Carc.CARC_288:
            return carc_288()
        if self is Carc.CARC_289:
            return carc_289()
        if self is Carc.CARC_290:
            return carc_290()
        if self is Carc.CARC_291:
            return carc_291()
        if self is Carc.CARC_292:
            return carc_292()
        if self is Carc.CARC_293:
            return carc_293()
        if self is Carc.CARC_294:
            return carc_294()
        if self is Carc.CARC_295:
            return carc_295()
        if self is Carc.CARC_296:
            return carc_296()
        if self is Carc.CARC_297:
            return carc_297()
        if self is Carc.CARC_298:
            return carc_298()
        if self is Carc.CARC_299:
            return carc_299()
        if self is Carc.CARC_300:
            return carc_300()
        if self is Carc.CARC_301:
            return carc_301()
        if self is Carc.CARC_302:
            return carc_302()
        if self is Carc.CARC_303:
            return carc_303()
        if self is Carc.CARC_304:
            return carc_304()
        if self is Carc.CARC_305:
            return carc_305()
        if self is Carc.CARC_A_0:
            return carc_a_0()
        if self is Carc.CARC_A_1:
            return carc_a_1()
        if self is Carc.CARC_A_5:
            return carc_a_5()
        if self is Carc.CARC_A_6:
            return carc_a_6()
        if self is Carc.CARC_A_8:
            return carc_a_8()
        if self is Carc.CARC_B_1:
            return carc_b_1()
        if self is Carc.CARC_B_4:
            return carc_b_4()
        if self is Carc.CARC_B_7:
            return carc_b_7()
        if self is Carc.CARC_B_8:
            return carc_b_8()
        if self is Carc.CARC_B_9:
            return carc_b_9()
        if self is Carc.CARC_B_10:
            return carc_b_10()
        if self is Carc.CARC_B_11:
            return carc_b_11()
        if self is Carc.CARC_B_12:
            return carc_b_12()
        if self is Carc.CARC_B_13:
            return carc_b_13()
        if self is Carc.CARC_B_14:
            return carc_b_14()
        if self is Carc.CARC_B_15:
            return carc_b_15()
        if self is Carc.CARC_B_16:
            return carc_b_16()
        if self is Carc.CARC_B_20:
            return carc_b_20()
        if self is Carc.CARC_B_22:
            return carc_b_22()
        if self is Carc.CARC_B_23:
            return carc_b_23()
        if self is Carc.CARC_P_1:
            return carc_p_1()
        if self is Carc.CARC_P_2:
            return carc_p_2()
        if self is Carc.CARC_P_3:
            return carc_p_3()
        if self is Carc.CARC_P_4:
            return carc_p_4()
        if self is Carc.CARC_P_5:
            return carc_p_5()
        if self is Carc.CARC_P_6:
            return carc_p_6()
        if self is Carc.CARC_P_7:
            return carc_p_7()
        if self is Carc.CARC_P_8:
            return carc_p_8()
        if self is Carc.CARC_P_9:
            return carc_p_9()
        if self is Carc.CARC_P_10:
            return carc_p_10()
        if self is Carc.CARC_P_11:
            return carc_p_11()
        if self is Carc.CARC_P_12:
            return carc_p_12()
        if self is Carc.CARC_P_13:
            return carc_p_13()
        if self is Carc.CARC_P_14:
            return carc_p_14()
        if self is Carc.CARC_P_15:
            return carc_p_15()
        if self is Carc.CARC_P_16:
            return carc_p_16()
        if self is Carc.CARC_P_17:
            return carc_p_17()
        if self is Carc.CARC_P_18:
            return carc_p_18()
        if self is Carc.CARC_P_19:
            return carc_p_19()
        if self is Carc.CARC_P_20:
            return carc_p_20()
        if self is Carc.CARC_P_21:
            return carc_p_21()
        if self is Carc.CARC_P_22:
            return carc_p_22()
        if self is Carc.CARC_P_23:
            return carc_p_23()
        if self is Carc.CARC_P_24:
            return carc_p_24()
        if self is Carc.CARC_P_25:
            return carc_p_25()
        if self is Carc.CARC_P_26:
            return carc_p_26()
        if self is Carc.CARC_P_27:
            return carc_p_27()
        if self is Carc.CARC_P_28:
            return carc_p_28()
        if self is Carc.CARC_P_29:
            return carc_p_29()
        if self is Carc.CARC_P_30:
            return carc_p_30()
        if self is Carc.CARC_P_31:
            return carc_p_31()
        if self is Carc.CARC_P_32:
            return carc_p_32()
        if self is Carc.CARC_17:
            return carc_17()
        if self is Carc.CARC_25:
            return carc_25()
        if self is Carc.CARC_28:
            return carc_28()
        if self is Carc.CARC_30:
            return carc_30()
        if self is Carc.CARC_36:
            return carc_36()
        if self is Carc.CARC_37:
            return carc_37()
        if self is Carc.CARC_38:
            return carc_38()
        if self is Carc.CARC_41:
            return carc_41()
        if self is Carc.CARC_42:
            return carc_42()
        if self is Carc.CARC_43:
            return carc_43()
        if self is Carc.CARC_46:
            return carc_46()
        if self is Carc.CARC_47:
            return carc_47()
        if self is Carc.CARC_48:
            return carc_48()
        if self is Carc.CARC_52:
            return carc_52()
        if self is Carc.CARC_57:
            return carc_57()
        if self is Carc.CARC_62:
            return carc_62()
        if self is Carc.CARC_63:
            return carc_63()
        if self is Carc.CARC_64:
            return carc_64()
        if self is Carc.CARC_65:
            return carc_65()
        if self is Carc.CARC_67:
            return carc_67()
        if self is Carc.CARC_68:
            return carc_68()
        if self is Carc.CARC_71:
            return carc_71()
        if self is Carc.CARC_72:
            return carc_72()
        if self is Carc.CARC_73:
            return carc_73()
        if self is Carc.CARC_77:
            return carc_77()
        if self is Carc.CARC_79:
            return carc_79()
        if self is Carc.CARC_80:
            return carc_80()
        if self is Carc.CARC_81:
            return carc_81()
        if self is Carc.CARC_82:
            return carc_82()
        if self is Carc.CARC_83:
            return carc_83()
        if self is Carc.CARC_84:
            return carc_84()
        if self is Carc.CARC_86:
            return carc_86()
        if self is Carc.CARC_87:
            return carc_87()
        if self is Carc.CARC_88:
            return carc_88()
        if self is Carc.CARC_92:
            return carc_92()
        if self is Carc.CARC_93:
            return carc_93()
        if self is Carc.CARC_98:
            return carc_98()
        if self is Carc.CARC_99:
            return carc_99()
        if self is Carc.CARC_113:
            return carc_113()
        if self is Carc.CARC_120:
            return carc_120()
        if self is Carc.CARC_123:
            return carc_123()
        if self is Carc.CARC_124:
            return carc_124()
        if self is Carc.CARC_126:
            return carc_126()
        if self is Carc.CARC_127:
            return carc_127()
        if self is Carc.CARC_138:
            return carc_138()
        if self is Carc.CARC_141:
            return carc_141()
        if self is Carc.CARC_145:
            return carc_145()
        if self is Carc.CARC_156:
            return carc_156()
        if self is Carc.CARC_162:
            return carc_162()
        if self is Carc.CARC_165:
            return carc_165()
        if self is Carc.CARC_168:
            return carc_168()
        if self is Carc.CARC_191:
            return carc_191()
        if self is Carc.CARC_196:
            return carc_196()
        if self is Carc.CARC_214:
            return carc_214()
        if self is Carc.CARC_217:
            return carc_217()
        if self is Carc.CARC_218:
            return carc_218()
        if self is Carc.CARC_220:
            return carc_220()
        if self is Carc.CARC_221:
            return carc_221()
        if self is Carc.CARC_230:
            return carc_230()
        if self is Carc.CARC_244:
            return carc_244()
        if self is Carc.CARC_255:
            return carc_255()
        if self is Carc.CARC_A_2:
            return carc_a_2()
        if self is Carc.CARC_A_3:
            return carc_a_3()
        if self is Carc.CARC_A_4:
            return carc_a_4()
        if self is Carc.CARC_A_7:
            return carc_a_7()
        if self is Carc.CARC_B_2:
            return carc_b_2()
        if self is Carc.CARC_B_3:
            return carc_b_3()
        if self is Carc.CARC_B_5:
            return carc_b_5()
        if self is Carc.CARC_B_6:
            return carc_b_6()
        if self is Carc.CARC_B_17:
            return carc_b_17()
        if self is Carc.CARC_B_18:
            return carc_b_18()
        if self is Carc.CARC_B_19:
            return carc_b_19()
        if self is Carc.CARC_B_21:
            return carc_b_21()
        if self is Carc.CARC_D_1:
            return carc_d_1()
        if self is Carc.CARC_D_2:
            return carc_d_2()
        if self is Carc.CARC_D_3:
            return carc_d_3()
        if self is Carc.CARC_D_4:
            return carc_d_4()
        if self is Carc.CARC_D_5:
            return carc_d_5()
        if self is Carc.CARC_D_6:
            return carc_d_6()
        if self is Carc.CARC_D_7:
            return carc_d_7()
        if self is Carc.CARC_D_8:
            return carc_d_8()
        if self is Carc.CARC_D_9:
            return carc_d_9()
        if self is Carc.CARC_D_10:
            return carc_d_10()
        if self is Carc.CARC_D_11:
            return carc_d_11()
        if self is Carc.CARC_D_12:
            return carc_d_12()
        if self is Carc.CARC_D_14:
            return carc_d_14()
        if self is Carc.CARC_D_15:
            return carc_d_15()
        if self is Carc.CARC_D_16:
            return carc_d_16()
        if self is Carc.CARC_D_17:
            return carc_d_17()
        if self is Carc.CARC_D_18:
            return carc_d_18()
        if self is Carc.CARC_D_19:
            return carc_d_19()
        if self is Carc.CARC_D_20:
            return carc_d_20()
        if self is Carc.CARC_D_21:
            return carc_d_21()
        if self is Carc.CARC_D_22:
            return carc_d_22()
        if self is Carc.CARC_D_23:
            return carc_d_23()
        if self is Carc.CARC_W_1:
            return carc_w_1()
        if self is Carc.CARC_W_2:
            return carc_w_2()
        if self is Carc.CARC_W_3:
            return carc_w_3()
        if self is Carc.CARC_W_4:
            return carc_w_4()
        if self is Carc.CARC_W_5:
            return carc_w_5()
        if self is Carc.CARC_W_6:
            return carc_w_6()
        if self is Carc.CARC_W_7:
            return carc_w_7()
        if self is Carc.CARC_W_8:
            return carc_w_8()
        if self is Carc.CARC_W_9:
            return carc_w_9()
        if self is Carc.CARC_Y_1:
            return carc_y_1()
        if self is Carc.CARC_Y_2:
            return carc_y_2()
        if self is Carc.CARC_Y_3:
            return carc_y_3()
        if self is Carc.UNKNOWN:
            return unknown()
        return _unknown_member(self._value_)
