# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .raw_client import AsyncRawOrganizationServiceFacilitiesClient, RawOrganizationServiceFacilitiesClient
from .resources.v_2.client import AsyncV2Client, V2Client


class OrganizationServiceFacilitiesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawOrganizationServiceFacilitiesClient(client_wrapper=client_wrapper)
        self.v_2 = V2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawOrganizationServiceFacilitiesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawOrganizationServiceFacilitiesClient
        """
        return self._raw_client


class AsyncOrganizationServiceFacilitiesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawOrganizationServiceFacilitiesClient(client_wrapper=client_wrapper)
        self.v_2 = AsyncV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawOrganizationServiceFacilitiesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawOrganizationServiceFacilitiesClient
        """
        return self._raw_client
