# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class CandidApiClientEnvironment:
    PRODUCTION: CandidApiClientEnvironment
    STAGING: CandidApiClientEnvironment
    CANDID_STAGING: CandidApiClientEnvironment

    def __init__(self, *, candid_api: str, pre_encounter: str):
        self.candid_api = candid_api
        self.pre_encounter = pre_encounter


CandidApiClientEnvironment.PRODUCTION = CandidApiClientEnvironment(
    candid_api="https://api.joincandidhealth.com", pre_encounter="https://pre-api.joincandidhealth.com"
)
CandidApiClientEnvironment.STAGING = CandidApiClientEnvironment(
    candid_api="https://api-staging.joincandidhealth.com", pre_encounter="https://pre-api-staging.joincandidhealth.com"
)
CandidApiClientEnvironment.CANDID_STAGING = CandidApiClientEnvironment(
    candid_api="https://staging-api.joincandidhealth.com", pre_encounter="https://staging-pre-api.joincandidhealth.com"
)
