# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .raw_client import AsyncRawFeeSchedulesClient, RawFeeSchedulesClient
from .resources.v_3.client import AsyncV3Client, V3Client


class FeeSchedulesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFeeSchedulesClient(client_wrapper=client_wrapper)
        self.v_3 = V3Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFeeSchedulesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFeeSchedulesClient
        """
        return self._raw_client


class AsyncFeeSchedulesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFeeSchedulesClient(client_wrapper=client_wrapper)
        self.v_3 = AsyncV3Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFeeSchedulesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFeeSchedulesClient
        """
        return self._raw_client
