# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrganizationProviderSortOptions(str, enum.Enum):
    PROVIDER_NAME_ASC = "provider_name:asc"
    PROVIDER_NAME_DESC = "provider_name:desc"
    NPI_ASC = "npi:asc"
    NPI_DESC = "npi:desc"
    _UNKNOWN = "__ORGANIZATIONPROVIDERSORTOPTIONS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "OrganizationProviderSortOptions":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        provider_name_asc: typing.Callable[[], T_Result],
        provider_name_desc: typing.Callable[[], T_Result],
        npi_asc: typing.Callable[[], T_Result],
        npi_desc: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is OrganizationProviderSortOptions.PROVIDER_NAME_ASC:
            return provider_name_asc()
        if self is OrganizationProviderSortOptions.PROVIDER_NAME_DESC:
            return provider_name_desc()
        if self is OrganizationProviderSortOptions.NPI_ASC:
            return npi_asc()
        if self is OrganizationProviderSortOptions.NPI_DESC:
            return npi_desc()
        return _unknown_member(self._value_)
