# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....invoices.resources.v_2.types.invoice_status import InvoiceStatus
from .invoice_item_info_update import InvoiceItemInfoUpdate


class ImportInvoiceUpdateRequest(UniversalBaseModel):
    customer_invoice_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Link to the patient view of the invoice in the third-party service
    """

    status: typing.Optional[InvoiceStatus] = None
    note: typing.Optional[str] = None
    due_date: typing.Optional[dt.date] = None
    items: typing.Optional[InvoiceItemInfoUpdate] = pydantic.Field(default=None)
    """
    None here represents there is no update to the invoice items
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
